@@ -2,25 +2,27 @@ from fastapi_helpers.workers import Worker
 from fastapi_helpers.logging import DefaultLogger
 from fastapi_helpers.middlewares import HeadersMiddleware
 from fastapi_helpers.routes import (
-    DefaultModelRouter, 
-    load_data_callback, 
-    Pagination,   
+    DefaultModelRouter,
+    load_data_callback,
+    Pagination,
 )
 from fastapi_helpers.crud import BaseCrud, to_dict
 from fastapi_helpers.security import Encoder
 from fastapi_helpers.settings import DefaultSettings
+from fastapi_helpers.db import DbConfig
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
 __all__ = [
     "Worker",
     "DefaultLogger",
+    "DbConfig",
     "HeadersMiddleware",
     "DefaultModelRouter",
     "load_data_callback",
     "Pagination",
-    "BaseCrud", 
+    "BaseCrud",
     "to_dict",
     "Encoder",
     "DefaultSettings"
-]
\ No newline at end of file
+]
